.. :changelog:

History
-------

0.8.0
-----

* Allowing to choose resolution and temporal scale.

0.7.0 (2017-05-11)
------------------

* New generic crop functionality.
* Interpolate in steps, in order: time, lat x lon, and finally z. Gives better results for profiles.

0.6.0 (2016-04-14)
------------------

* Adding CSIRO Atlas of Regional Seas (CARS), another climatology for temperature and salinity.

0.4.0 (2016-03-29)
------------------

* Added etopo5, a world wide bathymetry. Some of this code has its origins on pyAVISO and CoTeDe.

0.2.0 (2016-03)
------------------

* Renamed package to OceansDB, planning to include other climatologies and references.

0.1.0 (2016-02-09)
------------------

* Generalized interpolator. Extract climatology for point, profile or section.

0.0.1 (2015-12-13)
------------------

* First release on PyPI. Extracted from CoTeDe to be a standalone package.

pre-released (~2006)
--------------------

* The first version was developed in support to quality control thermosalinographs at NOAA. It was later injected inside CoTeDe.
